<?php

	/**
	 * Verification de santé du plugin
	 */
		function ghl_health_check(){
			global $wpdb;
			// Verifie que les base de donnés existe
			$missing_database = false;
			$missing_insert = false;

			$wp_table_app = $wpdb->prefix.ghl_bdd_table_app;
			if($wpdb->get_var("show tables like '{$wp_table_app}'") != $wp_table_app)
			{
				$missing_database = true;
				$missing_insert = true;
			}else{
				$wp_select = "SELECT * from ".$wp_table_app;
				$ghl_app = $wpdb->get_row($wp_select,ARRAY_A);
				if(empty($ghl_app['wizard'])){
					ghl_delect_base();
					ghl_create_base();
					ghl_insert_table();
					wp_redirect(get_admin_url('','admin.php?page=ghl_wizard'));
					exit;
				}
			}
			if($missing_database){
				ghl_create_base();
			}
			if($missing_insert){
				ghl_insert_table();
			}
		}
		add_filter( 'init', 'ghl_health_check' );

	/**
	 * Fonction de tampon de sortie
	 * Cela permettra à une redirection d'avoir lieu avant
	 * que le chargement de la page initiale ne soit terminé.
	 */
		function ghl_output_buffer() {
		    ob_start();
		}
		add_action( 'init', 'ghl_output_buffer' );
		
	/**
	 * Activation du plugin
	 */
		function ghl_activation( $network_wide ) {
			global $wpdb;
			if ( is_multisite() && $network_wide ) {
				$blog_ids = $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" );
				foreach ( $blog_ids as $blog_id ) {
					switch_to_blog( $blog_id );
					ghl_create_base();
					restore_current_blog();
				}
			} else {
				ghl_create_base();
			}
			ghl_insert_table();
			add_option('ghl_activation_redirect', true);
		}
		register_activation_hook( ghl_plugin_file, 'ghl_activation' );

		function ghl_activation_redirect(){
			if (get_option('ghl_activation_redirect', false)) {
			    delete_option('ghl_activation_redirect');
			    if(!isset($_GET['activate-multi']))
			    {
			        wp_redirect(get_admin_url('','admin.php?page=ghl_wizard'));
			        exit;
			    }
			 }
		}
		add_action( 'admin_init', 'ghl_activation_redirect' );

		function ghl_create_base(){
			global $wpdb;
			$wp_table_app = $wpdb->prefix.ghl_bdd_table_app;
			if($wpdb->get_var("show tables like '{$wp_table_app}'") != $wp_table_app)
			{
				$req_sql = "CREATE TABLE " . $wp_table_app . " (`id` mediumint(9) NOT NULL AUTO_INCREMENT, `uuid` VARCHAR(225), `wp_activation` VARCHAR(225), `oauth` LONGTEXT, `oauth_tmp`  LONGTEXT, `settings` LONGTEXT,  `wizard` LONGTEXT, `last_backup` VARCHAR(225), `version` TEXT, `hash` VARCHAR(225), UNIQUE KEY id (id));";
				$wpdb->query($req_sql);
			}
		}

		function ghl_insert_table(){
			global $wpdb;
			$wp_table_app = $wpdb->prefix.ghl_bdd_table_app;
			$wpdb->query($wpdb->prepare("INSERT INTO $wp_table_app (uuid) VALUES(%s)", array(ghl_fcnt_uuid())));

			if ( function_exists( 'get_plugin_data' ) ) {
				$plugin_data = get_plugin_data( ghl_plugin_file  );
				$plugin_version = $plugin_data['Version'];
			}

			if(!empty($plugin_version)){
				$wpdb->query( $wpdb->prepare( "UPDATE $wp_table_app SET version = %s WHERE id = %d", $plugin_version, 1));
			}

			$start_wizard = bin2hex(json_encode([
				"step" => 1
			]));
			$wpdb->query( $wpdb->prepare( "UPDATE $wp_table_app SET wizard = %s WHERE id = %d", $start_wizard, 1));
		}

	/**
	 * Désactivation du plugin
	 */
		function ghl_desactivation() {
			global $wpdb;
			if ( is_multisite() && $network_wide ) {
				$blog_ids = $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" );
				foreach ( $blog_ids as $blog_id ) {
					switch_to_blog( $blog_id );
					ghl_delect_base();
					restore_current_blog();
				}
			} else {
				ghl_delect_base();
			}
		}
		register_deactivation_hook ( ghl_plugin_file, 'ghl_desactivation' );

	/**
	 * Nettoyage de la base de donnée
	 */
		function ghl_delect_base(){
			global $wpdb;
			$wp_table_app = $wpdb->prefix.ghl_bdd_table_app;
			$req_sql = "DROP TABLE IF EXISTS " . $wp_table_app. ";";
			$wpdb->query($req_sql);
		}

	/**
	 * Chargement des fichiers langue
	 */
		function ghl_load_textdomain() {
			load_plugin_textdomain( 'app_ghostlink', false, ghl_plugin_name. '/languages' );
		}
		add_action( 'init', 'ghl_load_textdomain' );


	/**
	  * Chargement des defines
	  */
		add_filter( 'init', 'ghl_define' );
		$ghl_define = ghl_define();
		global $ghl_define;

	/**
	 * 	Declanche la vérification d'authentification
	 */
		function ghl_page_oauth() {
			global $ghl_define;
			if(isset($_GET['page'])){
				$screen = $_GET['page'];
				if(in_array($screen, $ghl_define['app']['wordpress_oauth'], true)){
					$wp_oauth = ghl_wordpress_oauth();
					$info = $wp_oauth['info'];
					$resp = $wp_oauth['resp'];
					if($info['http_code'] == 301){
						wp_redirect(get_admin_url('','admin.php?page=ghl_auth_login'));
			    		exit;
					}
					if($info['http_code'] == 500){
						//
					}
					if($info['http_code'] == 401){
						if($resp['error']['name'] == 'bad_wp_token'){
							wp_redirect(get_admin_url('','admin.php?page=ghl_auth_login'));
			    			exit;
						}
					}
					if($info['http_code'] == 402){
						if($resp['error']['name'] == 'payment_required'){
							header('location:/account/subscription/');
							exit;
						}
					}
					if($info['http_code'] == 200){
						if(!$resp['success']['associated']){
							wp_redirect(get_admin_url('','admin.php?page=ghl_auth_wordpress'));
			    			exit;
						}
					}
				}
			}
		}
		add_action( 'admin_init', 'ghl_page_oauth' );

    /**
     * Récupération de la version du plugin
     */
		function ghl_get_version() {
			global $wpdb;
			$wp_table_app = $wpdb->prefix.ghl_bdd_table_app;
			if ( function_exists( 'get_plugin_data' ) ) {
				$plugin_data = get_plugin_data( ghl_plugin_file  );
				$plugin_version = $plugin_data['Version'];
			}
			if(!empty($plugin_version)){
				$wpdb->query( $wpdb->prepare( "UPDATE $wp_table_app SET version = %s WHERE id = %d", $plugin_version, 1));
				return $plugin_version;
			}else{
				$wp_select = "SELECT * from ".$wp_table_app;
				$ghl_app = $wpdb->get_row($wp_select,ARRAY_A);
				return $ghl_app['version'];
			}
		}

	/**
	 * Récupération des scripts, fonctions, librairies est feuilles de styles
	 */
		function ghl_hook_enqueue( $hook ) {
			/**
			 * Charge les librairies javascript
			 */
			foreach (glob(ghl_plugin_folder."/assets/js/lib/lib.*.js") as $file_name) {
				if (is_file($file_name)) {
					if(stripos(strtolower(basename($file_name)),'jquery') !== false){
						wp_enqueue_script( md5('ghl_'.basename($file_name).ghl_get_version()), ghl_plugin_url .'assets/js/lib/'. basename($file_name), array( 'jquery' ), md5(ghl_get_version()), true );
					}else{
						wp_enqueue_script( md5('ghl_'.basename($file_name).ghl_get_version()), ghl_plugin_url .'assets/js/lib/'. basename($file_name), array(), md5(ghl_get_version()), true );
					}
				}
			}

			/**
			 * Charge les functions javascript
			 */
			foreach (glob(ghl_plugin_folder."/assets/js/fcnt/fcnt.*.js") as $file_name) {
				if (is_file($file_name)) {
					if(stripos(strtolower(basename($file_name)),'jquery') !== false){
						$exp_file_name = explode('.js', basename($file_name));
						$ghl_file_name = str_replace('.', '_', $exp_file_name[0]);
						$ghl_translation_javascript = ghl_fcnt_locale($ghl_file_name);
						wp_register_script( md5('ghl_'.basename($file_name).ghl_get_version()), ghl_plugin_url .'assets/js/fcnt/'. basename($file_name),array( 'jquery' ), '1.0.0', true);
						wp_localize_script( md5('ghl_'.basename($file_name).ghl_get_version()), 'ghl_localize_'.$ghl_file_name, $ghl_translation_javascript);
						wp_enqueue_script( md5('ghl_'.basename($file_name).ghl_get_version()) );
					}else{
						$exp_file_name = explode('.js', basename($file_name));
						$ghl_file_name = str_replace('.', '_', $exp_file_name[0]);
						$ghl_translation_javascript = ghl_fcnt_locale($ghl_file_name);
						wp_register_script( md5('ghl_'.basename($file_name).ghl_get_version()), ghl_plugin_url .'assets/js/fcnt/'. basename($file_name));
						wp_localize_script( md5('ghl_'.basename($file_name).ghl_get_version()), 'ghl_localize_'.$ghl_file_name, $ghl_translation_javascript);
						wp_enqueue_script( md5('ghl_'.basename($file_name).ghl_get_version()) );
					}
				}
			}

			/**
			 * Charge les librairies stylesheet
			 */
			foreach (glob(ghl_plugin_folder."/assets/css/lib/lib.*.css") as $file_name) {
				if (is_file($file_name)) {
					wp_enqueue_style( md5('ghl_'.basename($file_name).ghl_get_version()), ghl_plugin_url .'assets/css/lib/'. basename($file_name), array(), md5(ghl_get_version()));
				}
			}

			/**
			 * Ajoute les stylesheet indispensable
		 	 */
			$files_name = [
				'stylesheet.css'
			];
			foreach ($files_name as $file_name) {
				wp_enqueue_style( md5('ghl_'.basename($file_name).ghl_get_version()), ghl_plugin_url .'assets/css/'. basename($file_name),array(), md5(ghl_get_version()));
			}
			$glob_tpl = glob(ghl_plugin_folder."/tpl/*/style.css");

			/**
			 * Charge le stylesheet des templates
			 */
			foreach ($glob_tpl as $ghl_folder) {
				preg_match('#tpl/(.*?)/style.css#', $ghl_folder, $matches);
				wp_enqueue_style( md5($ghl_folder.'/style.css'), ghl_plugin_url .'tpl/'.$matches[1].'/style.css', array(), md5(ghl_get_version()));
			}

			/**
			 * Récupération de la médiathèque WP
			 */
			wp_enqueue_media();
			if(isset($_GET['page'])){
				if($_GET['page']=='ghl_subscription' OR $_GET['page']=='ghl_tools' OR $_GET['page']=='ghl_editor' OR $_GET['page']=='ghl_account'){
					/**
					 * Charge l'intention de paiement api dans les paramètres
					 */
					wp_enqueue_script( md5('stripe_v3'), 'https://js.stripe.com/v3/', true );
				}
			}
		}
		add_action( 'admin_enqueue_scripts', 'ghl_hook_enqueue' );

	/**
	 * Récupération de la feuilles de styles frontEnd
	 */
		function ghl_hook_enqueue_frontend( $hook ) {
			wp_enqueue_script('custom-css', get_template_directory_uri() . '/custom.css');
		}
		add_action( 'wp_enqueue_scripts', 'ghl_hook_enqueue_frontend' );
		
	/**
	* Création des pages et du menu
	*/
	function ghl_adm_menu() {
		add_menu_page(
			'Ghostlink : '.__( 'My account', 'app_ghostlink' ),
			'Ghostlink',
			'administrator',
			'ghl_account',
			function() { ghl_callback("account"); },
			ghl_plugin_url.'assets/svg/gofghl.svg'
		);
		add_submenu_page(
			'ghl_account',
			'Ghostlink : '.__( 'My account', 'app_ghostlink' ),
			'1) '.__( 'My account', 'app_ghostlink' ),
			'administrator',
			'ghl_account'
		);
		add_submenu_page(
			'ghl_account',
			'Ghostlink : '.__( 'Settings', 'app_ghostlink' ),
			'2) '.__( 'Settings', 'app_ghostlink' ),
			'administrator',
			'ghl_settings',
			function() { ghl_callback("settings"); }
		);
		add_submenu_page(
			'Ghostlink',
			'Ghostlink : '.__( 'Login', 'app_ghostlink' ),
			'hidden',
			'administrator',
			'ghl_auth_login',
			function() { ghl_callback("auth_login"); }
		);
		add_submenu_page(
			'Ghostlink',
			'Ghostlink : '.__( 'Subscription', 'app_ghostlink' ),
			'hidden',
			'administrator',
			'ghl_subscription',
			function() { ghl_callback("subscription"); }
		);
		add_submenu_page(
			'Ghostlink',
			'Ghostlink : '.__( 'Forgot', 'app_ghostlink' ),
			'hidden',
			'administrator',
			'ghl_auth_forgot',
			function() { ghl_callback("auth_forgot"); }
		);
		add_submenu_page(
			'Ghostlink',
			'Ghostlink : '.__( 'Register', 'app_ghostlink' ),
			'hidden',
			'administrator',
			'ghl_auth_register',
			function() { ghl_callback("auth_register"); }
		);
		add_submenu_page(
			'Ghostlink',
			'Ghostlink : '.__( 'One-time password authentication', 'app_ghostlink' ),
			'hidden',
			'administrator',
			'ghl_auth_otp',
			function() { ghl_callback("auth_otp"); }
		);
		add_submenu_page(
		    'Ghostlink',
		    'Ghostlink : '.__( 'Associate Wordpress', 'app_rank4win' ),
		    'hidden',
		    'administrator',
		    'ghl_auth_wordpress',
		    function() { ghl_callback("auth_wordpress"); }
		);
		add_submenu_page(
			'Ghostlink',
			'Ghostlink : '.__( 'Update available', 'app_ghostlink' ),
			'hidden',
			'administrator',
			'ghl_update_available',
			function() { ghl_callback("update_available"); }
		);
		add_submenu_page(
			'Ghostlink',
			'Ghostlink : '.__( 'Your invoice in pdf format', 'app_rank4win' ),
			'hidden',
			'administrator',
			'ghl_download_invoice',
			'ghl_callback_download_invoice'
		 );
		add_submenu_page(
			'Ghostlink',
			'Ghostlink : '.__( 'Configuration of ghostlink', 'app_rank4win' ),
			'hidden',
			'administrator',
			'ghl_wizard',
			function() { ghl_callback("wizard"); }
	    );
	}
	add_action( 'admin_menu', 'ghl_adm_menu' );

	// PAGE : Télécharge la facture au format pdf
	function ghl_callback_download_invoice(){
		$filename = 'invoice_'.$_GET['invoice_id'].'.pdf';
		$target_dir = ghl_plugin_base.'/temp/';
		if(!empty($_GET['invoice_id']) AND file_exists($target_dir.$filename)){
			header("Pragma: public");
			header("Expires: 0");
			header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
			header("Content-Type: application/pdf");
			header("Content-Disposition: attachment; filename=$filename");
			header("Content-Transfer-Encoding: binary");
			header("Content-Length: ".filesize($target_dir.$filename));
			while (ob_get_level()) {
				ob_end_clean();
				@readfile($target_dir.$filename);
			}
			unlink($target_dir.$filename);
			die();
		}else{
			header('location:'.get_admin_url('','admin.php?page=ghl_account&tab=invoice'));
		}
	}

	/**
	 * Gestion des liens dans l'éditeur
	 */
		function ghl_box_link( $post_type ){
			ghl_callback("box_link");
		}
		add_action( 'admin_footer-post.php', 'ghl_box_link');
		add_action( 'admin_footer-post-new.php', 'ghl_box_link');
		add_action( 'admin_footer-widgets.php', 'ghl_box_link');

	/**
	 * Gestion des liens dans les pages
	 */
		function ghl_html_page(){
			ghl_callback('html_page');
		}
		add_action( 'wp_head', 'ghl_html_page', -1 );

	/**
	 * Récupère le template de la page
	 */
		function ghl_callback($a,$b = null) {
			$arr = [
				"folder" => $a,
				"data" => $b,
			];
			echo ghl_tpl($arr);
		}

	/**
	 * Récupération de la class walker
	 */
	
		if ( ! class_exists( 'Menu_Item_Custom_Fields' ) ){
			class ghl_custom_fields {
				/**
				* Ajouter un filtre
				*/
				public static function load() {
					add_filter( 'wp_edit_nav_menu_walker', array( __CLASS__, '_filter_walker' ), 99 );
				}

				/**
				* Permet d'injecter de nouveau élement à la configuration de la structure du menu
				*/
				public static function _filter_walker( $walker ) {
					$walker = 'ghl_walker';
					if ( ! class_exists( $walker ) ) {
						require_once dirname( __FILE__ ) . '/class.walker.php';
					}
					return $walker;
				}
			}
			//add_action( 'wp_loaded', array( 'ghl_custom_fields', 'load' ), 9 );
		}
		

	/**
	* MENU : Champ wordpress
	*/
		function ghl_custom_fields( $item_id, $item ) {
			global $wpdb;
			$wp_table_app = $wpdb->prefix.ghl_bdd_table_app;
			$wp_select = "SELECT * from ".$wp_table_app;
			$ghl_app = $wpdb->get_row($wp_select,ARRAY_A);

			if(!empty($ghl_app['settings']) AND ctype_xdigit($ghl_app['settings'])){
				$wp_setting = json_decode(hex2bin($ghl_app['settings']),true);
			}

			wp_nonce_field( 'menu_item_ghostlink_nonce', '_menu_item_ghostlink_nonce' );
			$menu_item_ghostlink = get_post_meta( $item_id, 'menu-item-ghostlink', true );

			$link_default = '';
			$link_show = '';
			$link_hidden = '';
			if(!empty($menu_item_ghostlink)){
				switch ($menu_item_ghostlink) {
					case 'link_show':
						$link_show = ' selected="selected"';
					break;
					case 'link_hidden':
						$link_hidden = ' selected="selected"';
					break;
					default:
						$link_default = ' selected="selected"';
					break;
				}
			}

			$tpl_type = '<label for="'.$item_id.'">Ghostlink <br /> <select id="menu-item-ghostlink-'.$item_id.'" name="menu-item-ghostlink['.$item_id.']"><option value="link_default"'.$link_default.'>'.__( 'Use the default ghostlink settings' , 'app_ghostlink' ).'</option><option value="link_show"'.$link_show.'>'.__( 'Leave the menu visible' , 'app_ghostlink' ).'</option><option value="link_hidden"'.$link_hidden.'>'.__( 'Obfuscate the menu' , 'app_ghostlink' ).'</option></select></label>';

			echo $tpl_type;
		}
		add_action( 'wp_nav_menu_item_custom_fields', 'ghl_custom_fields', 10, 2 );

	/**
	* MENU : Sauvegarde menu item meta
	*/
		function ghl_nav_update( $menu_id, $menu_item_db_id ) {

			if ( ! isset( $_POST['_menu_item_ghostlink_nonce'] ) || ! wp_verify_nonce( $_POST['_menu_item_ghostlink_nonce'], 'menu_item_ghostlink_nonce' ) ) {
				return $menu_id;
			}
			if ( isset( $_POST['menu-item-ghostlink'][$menu_item_db_id]  ) ) {
				$sanitized_data = sanitize_text_field( $_POST['menu-item-ghostlink'][$menu_item_db_id] );
				update_post_meta( $menu_item_db_id, 'menu-item-ghostlink', $sanitized_data );
			} else {
				delete_post_meta( $menu_item_db_id, 'menu-item-ghostlink' );
			}
		}
		add_action( 'wp_update_nav_menu_item', 'ghl_nav_update', 10, 2 );

	/**
	* MENU : Affichage du menu front
	*/
		function ghl_custom_menu_title( $title, $item ) {
			$custom_menu_meta = get_post_meta( $item->ID, 'menu-item-ghostlink', true );

			if ( ! empty( $custom_menu_meta ) ) {}
			return $title;
		}
		//add_filter( 'nav_menu_item_title', 'ghl_custom_menu_title', 10, 2 );	