<?php
  /**
   * Walker personnalisé
   */
    class ghl_cu_walker extends Walker
    {
	    /**
		 * Ce que la classe gère
		 */
		public $tree_type = array( 'post_type', 'taxonomy', 'custom' );

		/**
		 * Champs de la base de données à utiliser
		 */
		public $db_fields = array( 'parent' => 'menu_item_parent', 'id' => 'db_id' );

		/**
		 * Démarre la liste avant que les éléments ne soient ajoutés.
		 */
		public function start_lvl( &$output, $depth = 0, $args = array() ) {
			$indent = str_repeat("\t", $depth);
			$output .= "\n$indent<ul class=\"sub-menu\">\n";
		}

		/**
		 * Finit la liste d'après l'ajout des éléments.
		 */
		public function end_lvl( &$output, $depth = 0, $args = array() ) {
			$indent = str_repeat("\t", $depth);
			$output .= "$indent</ul>\n";
		}

		/**
		 * Démarre la sortie de l'élément.
		 */
		public function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
			$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
			$classes = empty( $item->classes ) ? array() : (array) $item->classes;
			$classes[] = 'menu-item-' . $item->ID;
               $item->ghostlink = get_post_meta( $item->ID, 'menu-item-ghostlink', true );

               /**
                * FIX pour récupérer la class de salient
                */
               $item->salient = get_post_meta( $item->ID, 'menu-item-nectar-button-style', true );
               if(!empty($item->salient)){
                    $classes[] = $item->salient;
               }

			/**
			 * Filtre les arguments pour un seul élément de menu de navigation.
			 */
			$args = apply_filters( 'nav_menu_item_args', $args, $item, $depth );

			/**
			 * Filtre la ou les classes CSS appliquées à l'élément de liste d'un élément de menu.
			 */
			$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args, $depth ) );
			$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

			/**
			 * Filtre l'ID appliqué à l'élément d'élément de liste d'un élément de menu.
			 */
			$id = apply_filters( 'nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args, $depth );
			$id = $id ? ' id="' . esc_attr( $id ) . '"' : '';
			$output .= $indent . '<li' . $id . $class_names . '>';
			$atts = array();
			$atts['title']  = ! empty( $item->attr_title ) ? $item->attr_title : '';
			$atts['target'] = ! empty( $item->target )     ? $item->target     : '';
			$atts['rel']    = ! empty( $item->xfn )        ? $item->xfn        : '';
			$atts['href']   = ! empty( $item->url )        ? $item->url        : '';
			$atts['data-ghostlink']   = ! empty( $item->ghostlink )  ?  $item->ghostlink : 'shown';

			/**
			 * Filtre les attributs HTML appliqués à l'élément d'ancrage d'un élément de menu.
			 */
			$atts = apply_filters( 'nav_menu_link_attributes', $atts, $item, $args, $depth );
			$attributes = '';
			foreach ( $atts as $attr => $value ) {
				if ( ! empty( $value ) ) {
					$value = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
					$attributes .= ' ' . $attr . '="' . $value . '"';
				}
			}
			/**
			 * Ce filtre est documenté dans
			 * wp-includes/post-template.php
			 */
			$title = apply_filters( 'the_title', $item->title, $item->ID );

			/**
			 * Filtre le titre d'un élément de menu.
			 */
			$title = apply_filters( 'nav_menu_item_title', $title, $item, $args, $depth );
			$item_output = $args->before;
			$item_output .= '<a'. $attributes .'>';
			$item_output .= $args->link_before . $title . $args->link_after;
			$item_output .= '</a>';
			$item_output .= $args->after;

			/**
			 * Filtre la sortie de démarrage d'un élément de menu.
			 */
			$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
		}

		/**
		 * Ferme la sortie de l'élément, si nécessaire.
		 */
		public function end_el( &$output, $item, $depth = 0, $args = array() ) {
			$output .= "</li>\n";
		}
    }
